@@ -1,10 +1,18 @@
-lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
+lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug, name = "")
 {
+  . <- NULL
+
   if (is(call, "name"))
     call = eval(call)
 
   if (LIDROPTIONS("debug"))
-    .las@data %$% eval(call) %>% .debug_metrics(call)
+  {
+    output = with(.las@data, eval(call))
+    .debug_metrics(output, call)
+  }
+
+  if (is(res, "RasterLayer"))
+    by = "RASTER"
 
   if(by %in% c("XY", "XYZ", "HEXA"))
   {
@@ -19,7 +27,6 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
     if(2 != length(start)) stop("Parameter 'start' should have a length of 2", call. = FALSE)
 
     ._class = "lasmetrics"
-
     by = group_grid(.las@data$X, .las@data$Y, res, start)
   }
   # Aggregation on XYZ (grid_metrics3d)
@@ -29,7 +36,6 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
     if(3 != length(start)) stop("Parameter 'start' should have a length of 3", call. = FALSE)
 
     ._class = "lasmetrics3d"
-
     by = group_grid_3d(.las@data$X, .las@data$Y, .las@data$Z, res, start)
   }
   # Aggregation on hexagonal cells (grid_hexametrics)
@@ -38,7 +44,7 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
     if (!requireNamespace("hexbin", quietly = TRUE))
       stop("'hexbin' package is needed for this function to work. Please install it.", call. = F)
 
-    res = ((2*res*res)/(3*sqrt(3))) %>% sqrt %>% round(2)
+    res = round(sqrt(((2*res*res)/(3*sqrt(3)))), 2)
 
     ext = extent(.las)
     xmin = round_any(ext@xmin, res)
@@ -54,8 +60,6 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
     dx = (xmax - xmin)
     dy = (ymax - ymin)
 
-
-
     xbins = (xmax - xmin)/(2*res)
 
     hbin_data  = hexbin::hexbin(.las@data$X, .las@data$Y, shape = dy/dx,  xbins = xbins, xbnds = c(xmin, xmax), IDs = TRUE)
@@ -65,18 +69,35 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
     hbin_pos_ids = hbin_pos[hbin_ids]
 
     ._class = "lashexametrics"
-
     by = list(Xr = hbin_coord$x[hbin_pos_ids], Yr = hbin_coord$y[hbin_pos_ids])
   }
-  # Aggregation on hexagonal cells (grid_hexametrics)
+  # Aggregation by trees (tree_metrics)
   else if (by == "TREE")
   {
-    if(! "treeID" %in% names(.las@data))
+    if(! name %in% names(.las@data))
       stop("The trees are not segmented yet. Please see function 'lastrees'.", call. = FALSE)
 
-    ._class = "lastreemetrics"
+    ._class = NULL
+    by = .las@data[, get(name)]
+  }
+  else if (by == "RASTER")
+  {
+    raster = res
+    res = raster::res(raster)
 
-    by = .las@data$treeID
+    if (res[1] !=  res[2])
+      stop("Rasters with different x y resolutions are not supported", call. = FALSE)
+
+    res = res[1]
+    cells = raster::cellFromXY(raster, .las@data[, .(X,Y), with = TRUE])
+    values = suppressWarnings(raster[cells])
+    X = raster::xFromCell(raster, cells)
+    Y = raster::yFromCell(raster, cells)
+    X[is.na(values)] = NA
+    Y[is.na(values)] = NA
+
+    by = list(Xgrid = X, Ygrid = Y)
+    ._class = "lasmetrics"
   }
 
   # split flightlines option is alway possible but wrapper functions (the exported one) can
@@ -86,7 +107,7 @@ lasaggregate = function(.las, by, call, res, start, colnames, splitlines, debug)
   else if(splitlines & !"flightlineID" %in% names(.las@data))
     lidRError("LDR7")
 
-  stat <- .las@data[, c(eval(call)), by = by]
+  stat <- .las@data[, if (!anyNA(.BY)) c(eval(call)), by = by]
 
   n = names(stat)
   n[1:length(colnames)] = colnames
