@@ -35,11 +35,14 @@
 #' @keywords internal
 set.colors = function(x, palette, trim = 1)
 {
+  if (all(is.na(x)))
+    return(rep("lightgrey", length(x)))
+
   ncolors = length(palette)
 
   if (trim < 1)
   {
-    n = x %>% stats::quantile(trim)
+    n = stats::quantile(x, trim)
     x[x > n] = n
   }
 
