@@ -5,9 +5,10 @@ project = catalog(LASfile)
 
 
 test_that("Cluster do not overlap", {
-  catalog_options(buffer = 15, multicore = 1, tiling_size = 120)
+  buffer(project) <- 15
+  tiling_size(project) <- 120
 
-  cluster = lidR:::catalog_makecluster(project, 1, 15, FALSE,size = 120)
+  cluster = lidR:::catalog_makecluster(project, 1)
 
   x = unlist(lapply(cluster, function(cl) {c(cl@bbox$xmin, cl@bbox$xmax)}))
   y = unlist(lapply(cluster, function(cl) {c(cl@bbox$ymin, cl@bbox$ymax)}))
@@ -17,10 +18,10 @@ test_that("Cluster do not overlap", {
 })
 
 test_that("No extra cluster are generated", {
+  buffer(project) <- 0
+  tiling_size(project) <- 160
 
-  catalog_options(multicore = 1, tiling_size = 160, buffer = 0)
-
-  cluster = lidR:::catalog_makecluster(project, 20, 0, FALSE, size = 160)
+  cluster = lidR:::catalog_makecluster(project, 20)
 
   x = unlist(lapply(cluster, function(cl) {c(cl@bbox$xmin, cl@bbox$xmax)}))
   y = unlist(lapply(cluster, function(cl) {c(cl@bbox$ymin, cl@bbox$ymax)}))
